Struct Antsw1DigUsr
#[repr(transparent)]pub struct Antsw1DigUsr(pub u32);Expand description
ANTSW1_DIG_USR register.
Tuple Fields
0: u32Implementations
impl Antsw1DigUsr
impl Antsw1DigUsr
pub const fn rx_time_to_switch(&self) -> u8
pub const fn rx_time_to_switch(&self) -> u8
specifies the exact timing of the antenna switching at receiver level (in AoA).
pub fn set_rx_time_to_switch(&mut self, val: u8)
pub fn set_rx_time_to_switch(&mut self, val: u8)
specifies the exact timing of the antenna switching at receiver level (in AoA).