Struct Antsw2DigUsr
#[repr(transparent)]pub struct Antsw2DigUsr(pub u32);Expand description
ANTSW2_DIG_USR register.
Tuple Fields
0: u32Implementations
impl Antsw2DigUsr
impl Antsw2DigUsr
pub const fn tx_time_to_switch(&self) -> u8
pub const fn tx_time_to_switch(&self) -> u8
specifies the exact timing of the antenna switching during transmission at LE_1M baud rate (in AoD).
pub fn set_tx_time_to_switch(&mut self, val: u8)
pub fn set_tx_time_to_switch(&mut self, val: u8)
specifies the exact timing of the antenna switching during transmission at LE_1M baud rate (in AoD).