Struct Antsw3DigUsr
#[repr(transparent)]pub struct Antsw3DigUsr(pub u32);Expand description
ANTSW3_DIG_USR register.
Tuple Fields
0: u32Implementations
impl Antsw3DigUsr
impl Antsw3DigUsr
pub const fn tx_time_to_switch_2m(&self) -> u8
pub const fn tx_time_to_switch_2m(&self) -> u8
specifies the exact timing of the antenna switching during transmission at LE_2M baud rate (in AoD).
pub fn set_tx_time_to_switch_2m(&mut self, val: u8)
pub fn set_tx_time_to_switch_2m(&mut self, val: u8)
specifies the exact timing of the antenna switching during transmission at LE_2M baud rate (in AoD).