Struct Cr0DigEng
#[repr(transparent)]pub struct Cr0DigEng(pub u32);Expand description
CR0_DIG_ENG register.
Tuple Fields
0: u32Implementations
impl Cr0DigEng
impl Cr0DigEng
pub const fn cr_gain_after(&self) -> u8
pub const fn cr_gain_after(&self) -> u8
Set the gain of the clock recovery loop before Access Address detection to the value.
pub fn set_cr_gain_after(&mut self, val: u8)
pub fn set_cr_gain_after(&mut self, val: u8)
Set the gain of the clock recovery loop before Access Address detection to the value.
pub const fn cr_gain_before(&self) -> u8
pub const fn cr_gain_before(&self) -> u8
Set the gain of the clock recovery loop before Access Address detection to the value.
pub fn set_cr_gain_before(&mut self, val: u8)
pub fn set_cr_gain_before(&mut self, val: u8)
Set the gain of the clock recovery loop before Access Address detection to the value.