Struct Cr0Lr
#[repr(transparent)]pub struct Cr0Lr(pub u32);Expand description
CR0_LR register.
Tuple Fields
0: u32Implementations
impl Cr0Lr
impl Cr0Lr
pub const fn cr_lr_gain_after(&self) -> u8
pub const fn cr_lr_gain_after(&self) -> u8
Set the gain of the clock recovery loop after Access Address detection to the value 2^(-CR_LR_GAIN_ AFTER) when the coded PHY is in use.
pub fn set_cr_lr_gain_after(&mut self, val: u8)
pub fn set_cr_lr_gain_after(&mut self, val: u8)
Set the gain of the clock recovery loop after Access Address detection to the value 2^(-CR_LR_GAIN_ AFTER) when the coded PHY is in use.
pub const fn cr_lr_gain_before(&self) -> u8
pub const fn cr_lr_gain_before(&self) -> u8
Set the gain of the clock recovery loop before Access Address detection to the value 2^(-CR_LR_GAIN_ BEFORE) when the coded PHY is in use.
pub fn set_cr_lr_gain_before(&mut self, val: u8)
pub fn set_cr_lr_gain_before(&mut self, val: u8)
Set the gain of the clock recovery loop before Access Address detection to the value 2^(-CR_LR_GAIN_ BEFORE) when the coded PHY is in use.