Struct DemodIq2DigTst
#[repr(transparent)]pub struct DemodIq2DigTst(pub u32);Expand description
DEMOD_IQ2_DIG_TST register.
Tuple Fields
0: u32Implementations
impl DemodIq2DigTst
impl DemodIq2DigTst
pub const fn extcfg_sampling_time(&self) -> u8
pub const fn extcfg_sampling_time(&self) -> u8
Defines the sampling time, when extended configuration is enabled:.
pub fn set_extcfg_sampling_time(&mut self, val: u8)
pub fn set_extcfg_sampling_time(&mut self, val: u8)
Defines the sampling time, when extended configuration is enabled:.
pub const fn extcfg_trig_selection(&self) -> u8
pub const fn extcfg_trig_selection(&self) -> u8
Defines the trigger/anchor point of the IQ sampling, when extended configuration is enabled:.
pub fn set_extcfg_trig_selection(&mut self, val: u8)
pub fn set_extcfg_trig_selection(&mut self, val: u8)
Defines the trigger/anchor point of the IQ sampling, when extended configuration is enabled:.