Struct Dtb5DigEng
#[repr(transparent)]pub struct Dtb5DigEng(pub u32);Expand description
DTB5_DIG_ENG register.
Tuple Fields
0: u32Implementations
impl Dtb5DigEng
impl Dtb5DigEng
pub const fn rxtx_start_sel(&self) -> bool
pub const fn rxtx_start_sel(&self) -> bool
enable the possibility to control some signals by the other register bits instead of system design:.
pub fn set_rxtx_start_sel(&mut self, val: bool)
pub fn set_rxtx_start_sel(&mut self, val: bool)
enable the possibility to control some signals by the other register bits instead of system design:.
pub fn set_tx_active(&mut self, val: bool)
pub fn set_tx_active(&mut self, val: bool)
Force TX_ACTIVE signal.
pub fn set_rx_active(&mut self, val: bool)
pub fn set_rx_active(&mut self, val: bool)
Force RX_ACTIVE signal.
pub const fn initialize(&self) -> bool
pub const fn initialize(&self) -> bool
Force INITIALIZE signal (emulate a token request of the IP_BLE).
pub fn set_initialize(&mut self, val: bool)
pub fn set_initialize(&mut self, val: bool)
Force INITIALIZE signal (emulate a token request of the IP_BLE).
pub const fn port_selected_en(&self) -> bool
pub const fn port_selected_en(&self) -> bool
enable port selection.
pub fn set_port_selected_en(&mut self, val: bool)
pub fn set_port_selected_en(&mut self, val: bool)
enable port selection.
pub const fn port_selected_0(&self) -> bool
pub const fn port_selected_0(&self) -> bool
force port_selected[0] signal.
pub fn set_port_selected_0(&mut self, val: bool)
pub fn set_port_selected_0(&mut self, val: bool)
force port_selected[0] signal.