Struct RxadcAnaUsr
#[repr(transparent)]pub struct RxadcAnaUsr(pub u32);Expand description
RXADC_ANA_USR register.
Tuple Fields
0: u32Implementations
impl RxadcAnaUsr
impl RxadcAnaUsr
pub const fn rfd_rxadc_delaytrim_i(&self) -> u8
pub const fn rfd_rxadc_delaytrim_i(&self) -> u8
ADC loop delay control bits for I channel to apply when SW overload is enabled.
pub fn set_rfd_rxadc_delaytrim_i(&mut self, val: u8)
pub fn set_rfd_rxadc_delaytrim_i(&mut self, val: u8)
ADC loop delay control bits for I channel to apply when SW overload is enabled.
pub const fn rfd_rxadc_delaytrim_q(&self) -> u8
pub const fn rfd_rxadc_delaytrim_q(&self) -> u8
ADC loop delay control bits for Q channel to apply when SW overload is enabled.
pub fn set_rfd_rxadc_delaytrim_q(&mut self, val: u8)
pub fn set_rfd_rxadc_delaytrim_q(&mut self, val: u8)
ADC loop delay control bits for Q channel to apply when SW overload is enabled.
pub const fn rxadc_delaytrim_i_tst_sel(&self) -> bool
pub const fn rxadc_delaytrim_i_tst_sel(&self) -> bool
Enable the SW overload on RXADX delay trimming.
pub fn set_rxadc_delaytrim_i_tst_sel(&mut self, val: bool)
pub fn set_rxadc_delaytrim_i_tst_sel(&mut self, val: bool)
Enable the SW overload on RXADX delay trimming.
pub const fn rxadc_delaytrim_q_tst_sel(&self) -> bool
pub const fn rxadc_delaytrim_q_tst_sel(&self) -> bool
Enable the SW overload on RXADX delay trimming.
pub fn set_rxadc_delaytrim_q_tst_sel(&mut self, val: bool)
pub fn set_rxadc_delaytrim_q_tst_sel(&mut self, val: bool)
Enable the SW overload on RXADX delay trimming.